@@ -1,27 +1,43 @@
 extractCPT <- function(x, graph, smooth=0){
   if (!inherits(x, c("data.frame","table", "xtabs")))
-    stop("'x' must be one of dataframe, table, xtabs")      
+    stop("'x' must be one of dataframe, table, xtabs")
   if (!inherits(graph, "graphNEL"))
     stop("'graph' must be a graphNEL object")
   if (!is.DAG(graph))
     stop("'graph' must be a DAG")
 
-  V   <- nodes(graph) 
+  V   <- nodes(graph)
   vpa <- vpar(graph)[V]
 
+  ##.vpa <<- vpa
+
   if (class(x)[1]=="data.frame"){
-    ans <- lapply(vpa, function(ss){xtabs(~., data=x[, ss, drop=FALSE])})
+      cat("extractCPT - data.frame\n")
+      ans <- lapply(vpa, function(ss){
+          ##cat(sprintf("---- %s ----\n", toString( ss )))
+          zzz <- xtabs(~., data=x[, ss, drop=FALSE])
+          ##print(zzz)
+          zzz
+      })
   } else {
-    ans <- lapply(vpa, function(ss){tableMargin(x, ss)})    
+    ans <- lapply(vpa, function(ss){tableMargin(x, ss)})
   }
-  
+
+  #.ans <<- ans
   ans <- lapply(ans, as.parray, normalize="first", smooth=smooth)
+  chk <- unlist(lapply(ans, function(zz) any(is.na(zz))))
+  nnn <- names(chk)[which(chk)]
+  if (length(nnn)>0){
+      cat(sprintf("NA's found in conditional probability table(s) for nodes: %s\n", toString(nnn)))
+      cat(sprintf("  ... consider using the 'smooth' argument\n"))
+  }
+
   ans
 }
 
 extractPOT <- function(x, graph, smooth=0){
   if (!inherits(x, c("data.frame","table")))
-    stop("'x' must be a dataframe or a table")      
+    stop("'x' must be a dataframe or a table")
   if (!inherits(graph, "graphNEL"))
     stop("'graph' must be a graphNEL object")
   if (!is.TUG(graph))
@@ -29,7 +45,7 @@ extractPOT <- function(x, graph, smooth=0){
 
   .rip  <- rip( graph )
 
-  if (class(x)=="data.frame"){
+  if (class(x)[1]=="data.frame"){
     ans <- .extractPOT_dataframe(x, .rip$cliques, .rip$sep, smooth=smooth)
   } else {
     ans <- .extractPOT_table(x, .rip$cliques, .rip$sep, smooth=smooth)
@@ -42,7 +58,7 @@ extractPOT <- function(x, graph, smooth=0){
   attr(ans, "dag")     <- dg        ## Needed to save network in Hugin format
   attr(ans, "cptlist") <- cptlist   ## Needed to save network in Hugin format
 
-  ans 
+  ans
 }
 
 .extractPOT_table <- function(x, cliq, seps=NULL, smooth=0){
@@ -68,7 +84,7 @@ extractPOT <- function(x, graph, smooth=0){
     cq   <- cliq[[ii]]
     sp   <- seps[[ii]]
     xxx  <- xtabs(~., data=x[ , cq, drop=FALSE])
-    #xxx  <- as.table(ftable(x[ , cq, drop=FALSE])) 
+    #xxx  <- as.table(ftable(x[ , cq, drop=FALSE]))
     t.cq <- tableMargin(xxx, cq) + smooth
     names(dimnames(t.cq)) <- cq
     if (!is.null(seps) && length(sp)>0){
